@@ -335,6 +335,7 @@ class FakeNetwork(object):
             'name': 'network-name-' + uuid.uuid4().hex,
             'status': 'ACTIVE',
             'description': 'network-description-' + uuid.uuid4().hex,
+            'mtu': '1350',
             'tenant_id': 'project-id-' + uuid.uuid4().hex,
             'admin_state_up': True,
             'shared': False,
@@ -347,7 +348,6 @@ class FakeNetwork(object):
             'availability_zone_hints': [],
             'is_default': False,
             'port_security_enabled': True,
-            'tags': ['test'],
             'qos_policy_id': 'qos-policy-id-' + uuid.uuid4().hex,
             'ipv4_address_scope': 'ipv4' + uuid.uuid4().hex,
             'ipv6_address_scope': 'ipv6' + uuid.uuid4().hex,
@@ -565,6 +565,7 @@ class FakePort(object):
             'device_id': 'device-id-' + uuid.uuid4().hex,
             'device_owner': 'compute:nova',
             'dns_assignment': [{}],
+            'dns_domain': 'dns-domain-' + uuid.uuid4().hex,
             'dns_name': 'dns-name-' + uuid.uuid4().hex,
             'extra_dhcp_opts': [{}],
             'fixed_ips': [{'ip_address': '10.0.0.3',
@@ -1131,6 +1132,7 @@ class FakeSecurityGroup(object):
             'description': 'security-group-description-' + uuid.uuid4().hex,
             'project_id': 'project-id-' + uuid.uuid4().hex,
             'security_group_rules': [],
+            'tags': []
         }
 
         # Overwrite default attributes.
@@ -1379,6 +1381,7 @@ class FakeFloatingIP(object):
             'tenant_id': 'project-id-' + uuid.uuid4().hex,
             'description': 'floating-ip-description-' + uuid.uuid4().hex,
             'qos_policy_id': 'qos-policy-id-' + uuid.uuid4().hex,
+            'tags': [],
         }
 
         # Overwrite default attributes.
