@@ -186,11 +186,21 @@ class CreateVolume(command.ShowOne):
                 image_client.images,
                 parsed_args.image).id
 
+        size = parsed_args.size
+
         snapshot = None
         if parsed_args.snapshot:
-            snapshot = utils.find_resource(
+            snapshot_obj = utils.find_resource(
                 volume_client.volume_snapshots,
-                parsed_args.snapshot).id
+                parsed_args.snapshot)
+            snapshot = snapshot_obj.id
+            # Cinder requires a value for size when creating a volume
+            # even if creating from a snapshot. Cinder will create the
+            # volume with at least the same size as the snapshot anyway,
+            # so since we have the object here, just override the size
+            # value if it's either not given or is smaller than the
+            # snapshot size.
+            size = max(size or 0, snapshot_obj.size)
 
         project = None
         if parsed_args.project:
@@ -205,7 +215,7 @@ class CreateVolume(command.ShowOne):
                 parsed_args.user).id
 
         volume = volume_client.volumes.create(
-            size=parsed_args.size,
+            size=size,
             snapshot_id=snapshot,
             name=parsed_args.name,
             description=parsed_args.description,
@@ -341,14 +351,14 @@ class ListVolume(command.Lister):
         )
         parser.add_argument(
             '--marker',
-            metavar='<marker>',
+            metavar='<volume>',
             help=_('The last volume ID of the previous page'),
         )
         parser.add_argument(
             '--limit',
             type=int,
             action=parseractions.NonNegativeAction,
-            metavar='<limit>',
+            metavar='<num-volumes>',
             help=_('Maximum number of volumes to display'),
         )
         return parser
@@ -387,7 +397,6 @@ class ListVolume(command.Lister):
                 'Metadata',
             ]
             column_headers = copy.deepcopy(columns)
-            column_headers[1] = 'Display Name'
             column_headers[4] = 'Type'
             column_headers[6] = 'Attached to'
             column_headers[7] = 'Properties'
@@ -400,7 +409,6 @@ class ListVolume(command.Lister):
                 'Attachments',
             ]
             column_headers = copy.deepcopy(columns)
-            column_headers[1] = 'Display Name'
             column_headers[4] = 'Attached to'
 
         # Cache the server list
@@ -432,7 +440,7 @@ class ListVolume(command.Lister):
             'all_tenants': all_projects,
             'project_id': project_id,
             'user_id': user_id,
-            'display_name': parsed_args.name,
+            'name': parsed_args.name,
             'status': parsed_args.status,
         }
 
@@ -441,6 +449,8 @@ class ListVolume(command.Lister):
             marker=parsed_args.marker,
             limit=parsed_args.limit,
         )
+        column_headers = utils.backward_compat_col_lister(
+            column_headers, parsed_args.columns, {'Display Name': 'Name'})
 
         return (column_headers,
                 (utils.get_item_properties(
